//= require <timeinfo>
//
Ext.namespace('dSS11', 'dSS11.config');

dSS11.AccessConfigPanel = Ext.extend(Ext.form.FormPanel,
    {
        initComponent: function()
        {

            this.webPassword = new Ext.form.FieldSet(
                {
                    layout: 'form',
                    title:  _("Web interface admin password"),
                    scope:  this,
                    items:  [
                        {
                            xtype: 'label',
                            cls: 'x-green-text',
                            text: _("Note: the password must not contain any " +
                                    "whitespaces")
                        },
                        {
                            xtype: 'box',
                            height: '10'
                        },
                        {
                            xtype: 'textfield',
                            width: 220,
                            name: 'currentpw',
                            ref: 'currentpw',
                            inputType: 'password',
                            allowBlank: false,
                            fieldLabel: _("Current password"),
                            maxLength: 64
                        },
                        {
                            xtype: 'textfield',
                            width: 220,
                            name: 'newpw',
                            ref: 'newpw',
                            inputType: 'password',
                            regex: new RegExp("^\\S+$"),
                            allowBlank: false,
                            fieldLabel: _("New password"),
                            maxLength: 64
                        },
                        {
                            xtype: 'textfield',
                            width: 220,
                            name: 'repeatpw',
                            ref: 'repeatpw',
                            inputType: 'password',
                            submitValue: false,
                            allowBlank: false,
                            regex: new RegExp("^\\S+$"),
                            fieldLabel: _("Repeat new password"),
                            maxLength: 64
                        },
                        {
                            xtype: 'panel',
                            bodyBorder: false,
                            width: 333,
                            buttons:
                            [
                                {
                                    xtype: 'button',
                                    text: _("Apply"),
                                    handler: this.setPassword.createDelegate(this)
                                },
                                {
                                    xtype: 'button',
                                    text: _("Cancel"),
                                    handler: this.cancel.createDelegate(this)
                                }
                            ]
                        }
                    ] // items
                } // field set
            );

            Ext.apply(this, {
                    padding: 6,
                    width: 360,
                    ref: 'passwordform',
                    id: 'passwordform',
                    scope: this,
                    items: [ this.webPassword ]
                }
            );

            dSS11.AccessConfigPanel.superclass.initComponent.apply(this, arguments);
        }, // initcomponent
        cancel: function() {
            this.webPassword.currentpw.setRawValue();
            this.webPassword.newpw.setRawValue();
            this.webPassword.repeatpw.setRawValue();
        },
        setPassword:  function() {
            if (!this.getForm().isValid()) {
                Ext.Msg.alert(_("Error"), _("The password is missing or invalid!"));
                return;
            }

            if (this.webPassword.newpw.getValue() !=
                this.webPassword.repeatpw.getValue())
            {
                this.webPassword.newpw.markInvalid();
                this.webPassword.repeatpw.markInvalid();

                Ext.Msg.alert(_("Error"), _("The passwords you entered do not match!"));

                Ext.Msg.show({
                    title:_("Error"),
                    msg: _("The passwords you entered do not match!"),
                    buttons: Ext.Msg.OK,
                    scope: this,
                    fn: function() {
                        this.webPassword.newpw.reset();
                        this.webPassword.repeatpw.reset();
                        this.webPassword.newpw.markInvalid();
                        this.webPassword.repeatpw.markInvalid();
                    }
                });
                return;
            }

            this.el.mask(_("Applying changes") + '...', 'x-mask-loading');

            this.getForm().submit({
                url: '/cgi-bin/setwebpasswrapper.sh',
                method: 'GET',
                scope: this,
                success: function(form, action) {
                    this.webPassword.currentpw.reset();
                    this.webPassword.newpw.reset();
                    this.webPassword.repeatpw.reset();
                    this.el.unmask();
                    dSS11.StatusBar.setMessage(_("Password changed"));
                },
                failure: function(form, action) {
                    this.el.unmask();
                    switch (action.failureType) {
                        case Ext.form.Action.CONNECT_FAILURE:
                            Ext.Msg.alert(_("Error"),
                                _("Ajax communication failed"));
                        break;
                        default:
                            Ext.Msg.alert(_("Error"),
                                    _("Could not set password") + ": " +
                                    _(action.result.message));
                        break;
                    }
                }
            });
        }
    }
);

Ext.reg('dss11accessconfig', dSS11.AccessConfigPanel);

