//= require <netconfpanel>
//= require <sysconfpanel>
//= require <mailconfigpanel>
//= require <accesspanel>
//= require <authpanel>
//= require <systemupdate>
//= require <maintenance>
//= require <addons>
//= require <logconfig>
//= require <logfiles>
//= require <supportrequest>
//= require <supportconfig>
//= require <help>

Ext.namespace('dSS11');

dSS11.NavPanel = Ext.extend(Ext.Panel, 
    {
        initComponent: function() 
        {

            var tabRecord = Ext.data.Record.create([ 
                    { 
                        name: "title", 
                        id: "id",
                        auto: "auto"
                    } 
                ]);

            var tabStore = new Ext.data.Store({}, tabRecord);

            var cpItems =
                [
                    {
                        title: _("Overview"),
                        xtype: 'panel',
                        hideBorders: true,
                        ref: 'overview',
                        autoLoad: 'cgi-bin/prodinfo.hs',
                        autoScroll: true,
                        auto: true
                    },
/*
                    {
                        title: _("Logged in Users"),
                        hideBorders: true,
                        xtype: 'panel',
                        ref: 'loggedinusers',
                        autoLoad: 'cgi-bin/who.hs',
                        auto: true
                    },
*/
                    {
                        title: _("Network Settings"),
                        ref: 'netconfig',
                        hideBorders: true,
                        xtype: 'dss11netconfig',
                        auto: false
                    },
                    {
                        title: _("System Settings"),
                        ref: 'sysconfig',
                        hideBorders: true,
                        xtype: 'dss11sysconfig',
                        auto: false
                    },
                    {
                        title: _("Mail Settings"),
                        ref: 'mailconfig',
                        hideBorders: true,
                        xtype: 'dss11mailconfig',
                        auto: false
                    }
                ];

            if (dSS11.config.dSSIntegration === true) {
                cpItems.push(
                {
                    title: _("Access Authorization"),
                    ref: 'authpanel',
                    hideBorders: true,
                    xtype: 'dss11authpanel',
                    auto: false
                });
            }

            cpItems = cpItems.concat(
                {
                    title: _("Password"),
                    ref: 'accessconfig',
                    hideBorders: true,
                    xtype: 'dss11accessconfig',
                    auto: false
                },
                {
                    title: _("System Maintenance"),
                    xtype: 'dss11sysmaintenance',
                    auto: false
                },
                /*
                {
                    title: _("Logfile Settings"),
                    ref: 'logconfig',
                    xtype: 'dss11logconfig',
                    auto: false
                },
                {
                    title: _("Support Settings"),
                    ref: 'supportconfig',
                    xtype: 'dss11supportconfig',
                    auto: false
                },
                {
                    title: _("Support Request"),
                    ref: 'supportrequest',
                    xtype: 'dss11supportrequest',
                    auto: false
                },*/
                {
                    title: _("Logging"),
                    ref: 'logging',
                    xtype: 'dss11logfiles',
                    auto: false
                },
                {
                    title: _("System Update"),
                    ref: 'sysupdate',
                    hideBorders: true,
                    xtype: 'dss11systemupdate',
                    auto: false
                }
            );

            if (dSS11.config.dSSIntegration === true) {
                cpItems.push(
                {
                    title: _("Property Tree"),
                    ref: 'proptree',
                    hideBorders: true,
                    xtype: 'dsssystempropertytree',
                    auto: false
                });
            }

            this.defaultSelection = 0;

            var contentPanel = 
            {
                ref: 'contentPanel',
                region: 'center',
                layout: 'card',
                hideBorders: true,
                split: true,
                items: cpItems
            };

            this.listView = new Ext.list.ListView(
                {
                    ref: 'listView',
                    store: tabStore,
                    singleSelect: true,
                    region: 'west',
                    hideHeaders: true,
                    columns: [{ header: 'name', dataIndex: 'title' }]
                }
            );

            var listHolder = new Ext.Panel(
                {
                    title: _("Menu"),
                    region: 'west',
                    layout: 'fit',
                    width: 190,
                    hideBorders: true,
                    split: true,
                    items: [ this.listView ] 
                }
            );

            Ext.apply(this, 
                {
                    layout: 'border',
                    items: [ listHolder, contentPanel ]
                }
            );

            dSS11.NavPanel.superclass.initComponent.apply(this, arguments);

            this.on(
                'beforerender',
                function(component) 
                {
                    if (this.initializedTabs) 
                    {
                        return;
                    }
        
                    // for each item in contentPanel
                    this.contentPanel.items.each(
                        function(item) 
                        {
                            var tab = new tabRecord(
                                {
                                    title: item.title,
                                    id: item.id,
                                    auto: item.auto
                                }
                            );
                            tabStore.add([tab]);
                        }, 
                        this
                    );

                    this.listView.on(
                        'afterrender',
                        function() 
                        {
                            this.listView.select(this.defaultSelection); 
                        },
                        this
                    );

                    this.listView.on(
                        'selectionchange',
                        function(listView, selections) 
                        {
                            this.contentPanel.layout.setActiveItem(selections[0].viewIndex);
                        },
                        this
                    );

                    this.listView.on(
                        'click',
                        function(listView, index)
                        {
                            if (listView.getRecord(listView.getNode(index)).get('auto') === true) {
                                Ext.getCmp(listView.getRecord(listView.getNode(index)).get('id')).doAutoLoad(); 
                            }
                        }
                    ); 
                    this.initializedTabs = true;
                },
                this
            ); // this.on

        } // initcomponent
    } // extend
);

Ext.reg('dss11navpanel', dSS11.NavPanel);
